@@ -96,7 +96,7 @@ QStringList deduplicateIconsByName(const QStringList &icons)
 
 } // namespace
 
-/**
+/*
  * Function to convert an uint32_t to AARRGGBB hex values.
  *
  * W A R N I N G !
@@ -128,7 +128,7 @@ static QString paletteId(const KIconColors &colors)
     return buffer;
 }
 
-/*** KIconThemeNode: A node in the icon theme dependency tree. ***/
+/* KIconThemeNode: A node in the icon theme dependency tree. */
 
 class KIconThemeNode
 {
@@ -682,8 +682,11 @@ QByteArray KIconLoaderPrivate::processSvg(const QString &path, KIconLoader::Stat
     QBuffer buffer(&processedContents);
     buffer.open(QIODevice::WriteOnly);
     QXmlStreamWriter writer(&buffer);
+    bool foundStyleSheet = false;
     while (!reader.atEnd()) {
-        if (reader.readNext() == QXmlStreamReader::StartElement //
+        reader.readNext();
+        if (!foundStyleSheet //
+            && reader.tokenType() == QXmlStreamReader::StartElement //
             && reader.qualifiedName() == QLatin1String("style") //
             && reader.attributes().value(QLatin1String("id")) == QLatin1String("current-color-scheme")) {
             writer.writeStartElement(QStringLiteral("style"));
@@ -693,6 +696,7 @@ QByteArray KIconLoaderPrivate::processSvg(const QString &path, KIconLoader::Stat
             while (reader.tokenType() != QXmlStreamReader::EndElement) {
                 reader.readNext();
             }
+            foundStyleSheet = true;
         } else if (reader.tokenType() != QXmlStreamReader::Invalid) {
             writer.writeCurrentToken(reader);
         }
@@ -950,12 +954,12 @@ QString KIconLoader::iconPath(const QString &_name, int group_or_size, bool canR
 
     QString path;
     if (group_or_size == KIconLoader::User) {
-        path = d->locate(name + QLatin1String(".png"));
+        path = d->locate(name + QLatin1String(".svg"));
         if (path.isEmpty()) {
             path = d->locate(name + QLatin1String(".svgz"));
         }
         if (path.isEmpty()) {
-            path = d->locate(name + QLatin1String(".svg"));
+            path = d->locate(name + QLatin1String(".png"));
         }
         if (path.isEmpty()) {
             path = d->locate(name + QLatin1String(".xpm"));
